@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-e3455ef9cbbd53ee4ffc7045c5d026cf
-key: yesod_0b3hheIb5Ve4uIZ3iHTfNA
+id: yesod-1.4.2-33f138f671b68cbd02e8db51ca6fb923
+key: yesod_8TmXj4Gh8RHKCkzeMfmQTi
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-0b3hheIb5Ve4uIZ3iHTfNA
+hs-libraries: HSyesod-1.4.2-8TmXj4Gh8RHKCkzeMfmQTi
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -46,12 +46,12 @@ depends:
     wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
     wai-extra-3.0.13.1-754076fbe6d9ad0271640500660355fd
     wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
-    warp-3.2.1-184b585d1fe25e67a905eacad9ccd211
+    warp-3.2.1-c746ace20dddea81145bc092568c441c
     yaml-0.8.15.3-09a15b752fd0338a3f112f0a1d663798
-    yesod-auth-1.4.12-cc89ddaa1d8ceca602ee7d4484044559
-    yesod-core-1.4.19-97e13dc735e6c4c26d8664b1b0881662
-    yesod-form-1.4.6-f33925874fe42e8068b104bdcab5984d
-    yesod-persistent-1.4.0.3-b0d59ef575a9f5abbc9cd66ae1d954b9
+    yesod-auth-1.4.12-2f987b8aa9a35f6cd9874700a626dfd6
+    yesod-core-1.4.19-69419c3f231fe1a580adea646932aded
+    yesod-form-1.4.6-c04dd4ec96d3036098fc231502078e2a
+    yesod-persistent-1.4.0.3-3432f935ad62b4f3fcea54734ae32e85
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
